Crate aec_rs_sys

Crate aec_rs_sys 

Structs

SpeexDecorrState_
SpeexEchoState_
Internal echo canceller state. Should never be accessed directly.
SpeexPreprocessState_
State of the preprocessor (one per channel). Should never be accessed directly.
__fsid_t

Constants

INT8_MAX
INT8_MIN
INT16_MAX
INT16_MIN
INT32_MAX
INT32_MIN
INTPTR_MAX
INTPTR_MIN
INT_FAST8_MAX
INT_FAST8_MIN
INT_FAST16_MAX
INT_FAST16_MIN
INT_FAST32_MAX
INT_FAST32_MIN
INT_LEAST8_MAX
INT_LEAST8_MIN
INT_LEAST16_MAX
INT_LEAST16_MIN
INT_LEAST32_MAX
INT_LEAST32_MIN
PTRDIFF_MAX
PTRDIFF_MIN
SIG_ATOMIC_MAX
SIG_ATOMIC_MIN
SIZE_MAX
SPEEX_ECHO_GET_FRAME_SIZE
SPEEX_ECHO_GET_IMPULSE_RESPONSE
SPEEX_ECHO_GET_IMPULSE_RESPONSE_SIZE
SPEEX_ECHO_GET_SAMPLING_RATE
SPEEX_ECHO_SET_SAMPLING_RATE
SPEEX_PREPROCESS_GET_AGC
SPEEX_PREPROCESS_GET_AGC_DECREMENT
SPEEX_PREPROCESS_GET_AGC_GAIN
SPEEX_PREPROCESS_GET_AGC_INCREMENT
SPEEX_PREPROCESS_GET_AGC_LEVEL
SPEEX_PREPROCESS_GET_AGC_LOUDNESS
SPEEX_PREPROCESS_GET_AGC_MAX_GAIN
SPEEX_PREPROCESS_GET_AGC_TARGET
SPEEX_PREPROCESS_GET_DENOISE
SPEEX_PREPROCESS_GET_DEREVERB
SPEEX_PREPROCESS_GET_DEREVERB_DECAY
SPEEX_PREPROCESS_GET_DEREVERB_LEVEL
SPEEX_PREPROCESS_GET_ECHO_STATE
SPEEX_PREPROCESS_GET_ECHO_SUPPRESS
SPEEX_PREPROCESS_GET_ECHO_SUPPRESS_ACTIVE
SPEEX_PREPROCESS_GET_NOISE_PSD
SPEEX_PREPROCESS_GET_NOISE_PSD_SIZE
SPEEX_PREPROCESS_GET_NOISE_SUPPRESS
SPEEX_PREPROCESS_GET_PROB
SPEEX_PREPROCESS_GET_PROB_CONTINUE
SPEEX_PREPROCESS_GET_PROB_START
SPEEX_PREPROCESS_GET_PSD
SPEEX_PREPROCESS_GET_PSD_SIZE
SPEEX_PREPROCESS_GET_VAD
SPEEX_PREPROCESS_SET_AGC
SPEEX_PREPROCESS_SET_AGC_DECREMENT
SPEEX_PREPROCESS_SET_AGC_INCREMENT
SPEEX_PREPROCESS_SET_AGC_LEVEL
SPEEX_PREPROCESS_SET_AGC_MAX_GAIN
SPEEX_PREPROCESS_SET_AGC_TARGET
SPEEX_PREPROCESS_SET_DENOISE
SPEEX_PREPROCESS_SET_DEREVERB
SPEEX_PREPROCESS_SET_DEREVERB_DECAY
SPEEX_PREPROCESS_SET_DEREVERB_LEVEL
SPEEX_PREPROCESS_SET_ECHO_STATE
SPEEX_PREPROCESS_SET_ECHO_SUPPRESS
SPEEX_PREPROCESS_SET_ECHO_SUPPRESS_ACTIVE
SPEEX_PREPROCESS_SET_NOISE_SUPPRESS
SPEEX_PREPROCESS_SET_PROB_CONTINUE
SPEEX_PREPROCESS_SET_PROB_START
SPEEX_PREPROCESS_SET_VAD
UINT8_MAX
UINT16_MAX
UINT32_MAX
UINTPTR_MAX
UINT_FAST8_MAX
UINT_FAST16_MAX
UINT_FAST32_MAX
UINT_LEAST8_MAX
UINT_LEAST16_MAX
UINT_LEAST32_MAX
WINT_MAX
WINT_MIN
_ATFILE_SOURCE
_BITS_STDINT_INTN_H
_BITS_STDINT_LEAST_H
_BITS_STDINT_UINTN_H
_BITS_TIME64_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_BITS_WCHAR_H
_DEFAULT_SOURCE
_FEATURES_H
_POSIX_C_SOURCE
_POSIX_SOURCE
_STDC_PREDEF_H
_STDINT_H
_SYS_CDEFS_H
__FD_SETSIZE
__GLIBC_MINOR__
__GLIBC_USE_C2X_STRTOL
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_DEPRECATED_SCANF
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_BFP_EXT_C2X
__GLIBC_USE_IEC_60559_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT_C2X
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_ISOC2X
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_GENERIC_SELECTION
__INO_T_MATCHES_INO64_T
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI
__OFF_T_MATCHES_OFF64_T
__RLIM_T_MATCHES_RLIM64_T
__STATFS_MATCHES_STATFS64
__STDC_IEC_559_COMPLEX__
__STDC_IEC_559__
__STDC_IEC_60559_BFP__
__STDC_IEC_60559_COMPLEX__
__STDC_ISO_10646__
__SYSCALL_WORDSIZE
__TIMESIZE
__USE_ATFILE
__USE_FORTIFY_LEVEL
__USE_ISOC11
__USE_ISOC95
__USE_ISOC99
__USE_MISC
__USE_POSIX
__USE_POSIX2
__USE_POSIX199309
__USE_POSIX199506
__USE_POSIX_IMPLICITLY
__USE_XOPEN2K
__USE_XOPEN2K8
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__glibc_c99_flexarr_available

Functions

speex_decorrelate
Remove correlation between the channels by modifying the phase and possibly adding noise in a way that is not (or little) perceptible. @param st Decorrelator state @param in Input audio in interleaved format @param out Result of the decorrelation (out may alias in) @param strength How much alteration of the audio to apply from 0 to 100.
speex_decorrelate_destroy
Destroy a Decorrelation state @param st State to destroy
speex_decorrelate_new
Create a state for the channel decorrelation algorithm This is useful for multi-channel echo cancellation only @param rate Sampling rate @param channels Number of channels (it’s a bit pointless if you don’t have at least 2) @param frame_size Size of the frame to process at ones (counting samples per channel)
speex_echo_cancel
Performs echo cancellation a frame (deprecated)
speex_echo_cancellation
Performs echo cancellation a frame, based on the audio sent to the speaker (no delay is added to playback in this form)
speex_echo_capture
Perform echo cancellation using internal playback buffer, which is delayed by two frames to account for the delay introduced by most soundcards (but it could be off!) @param st Echo canceller state @param rec Signal from the microphone (near end + far end echo) @param out Returns near-end signal with echo removed
speex_echo_ctl
Used like the ioctl function to control the echo canceller parameters
speex_echo_playback
Let the echo canceller know that a frame was just queued to the soundcard @param st Echo canceller state @param play Signal played to the speaker (received from far end)
speex_echo_state_destroy
Destroys an echo canceller state @param st Echo canceller state
speex_echo_state_init
Creates a new echo canceller state @param frame_size Number of samples to process at one time (should correspond to 10-20 ms) @param filter_length Number of samples of echo to cancel (should generally correspond to 100-500 ms) @return Newly-created echo canceller state
speex_echo_state_init_mc
Creates a new multi-channel echo canceller state @param frame_size Number of samples to process at one time (should correspond to 10-20 ms) @param filter_length Number of samples of echo to cancel (should generally correspond to 100-500 ms) @param nb_mic Number of microphone channels @param nb_speakers Number of speaker channels @return Newly-created echo canceller state
speex_echo_state_reset
Reset the echo canceller to its original state @param st Echo canceller state
speex_preprocess
Preprocess a frame (deprecated, use speex_preprocess_run() instead)
speex_preprocess_ctl
Used like the ioctl function to control the preprocessor parameters @param st Preprocessor state @param request ioctl-type request (one of the SPEEX_PREPROCESS_* macros) @param ptr Data exchanged to-from function @return 0 if no error, -1 if request in unknown
speex_preprocess_estimate_update
Update preprocessor state, but do not compute the output @param st Preprocessor state @param x Audio sample vector (in only). Must be same size as specified in speex_preprocess_state_init().
speex_preprocess_run
Preprocess a frame @param st Preprocessor state @param x Audio sample vector (in and out). Must be same size as specified in speex_preprocess_state_init(). @return Bool value for voice activity (1 for speech, 0 for noise/silence), ONLY if VAD turned on.
speex_preprocess_state_destroy
Destroys a preprocessor state @param st Preprocessor state to destroy
speex_preprocess_state_init
Creates a new preprocessing state. You MUST create one state per channel processed. @param frame_size Number of samples to process at one time (should correspond to 10-20 ms). Must be the same value as that used for the echo canceller for residual echo cancellation to work. @param sampling_rate Sampling rate used for the input. @return Newly created preprocessor state

Type Aliases

SpeexDecorrState
SpeexEchoState
Internal echo canceller state. Should never be accessed directly.
SpeexPreprocessState
State of the preprocessor (one per channel). Should never be accessed directly.
__blkcnt64_t
__blkcnt_t
__blksize_t
__caddr_t
__clock_t
__clockid_t
__daddr_t
__dev_t
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__int_least8_t
__int_least16_t
__int_least32_t
__int_least64_t
__intmax_t
__intptr_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds64_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__time_t
__timer_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uint_least8_t
__uint_least16_t
__uint_least32_t
__uint_least64_t
__uintmax_t
__useconds_t
int_fast8_t
int_fast16_t
int_fast32_t
int_fast64_t
int_least8_t
int_least16_t
int_least32_t
int_least64_t
intmax_t
spx_int16_t
spx_int32_t
spx_uint16_t
spx_uint32_t
uint_fast8_t
uint_fast16_t
uint_fast32_t
uint_fast64_t
uint_least8_t
uint_least16_t
uint_least32_t
uint_least64_t
uintmax_t