Structs
- Speex
Decorr State_ - Speex
Echo State_ - Internal echo canceller state. Should never be accessed directly.
- Speex
Preprocess State_ - State of the preprocessor (one per channel). Should never be accessed directly.
- __
fsid_ t
Constants
- INT8_
MAX - INT8_
MIN - INT16_
MAX - INT16_
MIN - INT32_
MAX - INT32_
MIN - INTPTR_
MAX - INTPTR_
MIN - INT_
FAST8_ MAX - INT_
FAST8_ MIN - INT_
FAST16_ MAX - INT_
FAST16_ MIN - INT_
FAST32_ MAX - INT_
FAST32_ MIN - INT_
LEAS T8_ MAX - INT_
LEAS T8_ MIN - INT_
LEAS T16_ MAX - INT_
LEAS T16_ MIN - INT_
LEAS T32_ MAX - INT_
LEAS T32_ MIN - PTRDIFF_
MAX - PTRDIFF_
MIN - SIG_
ATOMIC_ MAX - SIG_
ATOMIC_ MIN - SIZE_
MAX - SPEEX_
ECHO_ GET_ FRAME_ SIZE - SPEEX_
ECHO_ GET_ IMPULSE_ RESPONSE - SPEEX_
ECHO_ GET_ IMPULSE_ RESPONSE_ SIZE - SPEEX_
ECHO_ GET_ SAMPLING_ RATE - SPEEX_
ECHO_ SET_ SAMPLING_ RATE - SPEEX_
PREPROCESS_ GET_ AGC - SPEEX_
PREPROCESS_ GET_ AGC_ DECREMENT - SPEEX_
PREPROCESS_ GET_ AGC_ GAIN - SPEEX_
PREPROCESS_ GET_ AGC_ INCREMENT - SPEEX_
PREPROCESS_ GET_ AGC_ LEVEL - SPEEX_
PREPROCESS_ GET_ AGC_ LOUDNESS - SPEEX_
PREPROCESS_ GET_ AGC_ MAX_ GAIN - SPEEX_
PREPROCESS_ GET_ AGC_ TARGET - SPEEX_
PREPROCESS_ GET_ DENOISE - SPEEX_
PREPROCESS_ GET_ DEREVERB - SPEEX_
PREPROCESS_ GET_ DEREVERB_ DECAY - SPEEX_
PREPROCESS_ GET_ DEREVERB_ LEVEL - SPEEX_
PREPROCESS_ GET_ ECHO_ STATE - SPEEX_
PREPROCESS_ GET_ ECHO_ SUPPRESS - SPEEX_
PREPROCESS_ GET_ ECHO_ SUPPRESS_ ACTIVE - SPEEX_
PREPROCESS_ GET_ NOISE_ PSD - SPEEX_
PREPROCESS_ GET_ NOISE_ PSD_ SIZE - SPEEX_
PREPROCESS_ GET_ NOISE_ SUPPRESS - SPEEX_
PREPROCESS_ GET_ PROB - SPEEX_
PREPROCESS_ GET_ PROB_ CONTINUE - SPEEX_
PREPROCESS_ GET_ PROB_ START - SPEEX_
PREPROCESS_ GET_ PSD - SPEEX_
PREPROCESS_ GET_ PSD_ SIZE - SPEEX_
PREPROCESS_ GET_ VAD - SPEEX_
PREPROCESS_ SET_ AGC - SPEEX_
PREPROCESS_ SET_ AGC_ DECREMENT - SPEEX_
PREPROCESS_ SET_ AGC_ INCREMENT - SPEEX_
PREPROCESS_ SET_ AGC_ LEVEL - SPEEX_
PREPROCESS_ SET_ AGC_ MAX_ GAIN - SPEEX_
PREPROCESS_ SET_ AGC_ TARGET - SPEEX_
PREPROCESS_ SET_ DENOISE - SPEEX_
PREPROCESS_ SET_ DEREVERB - SPEEX_
PREPROCESS_ SET_ DEREVERB_ DECAY - SPEEX_
PREPROCESS_ SET_ DEREVERB_ LEVEL - SPEEX_
PREPROCESS_ SET_ ECHO_ STATE - SPEEX_
PREPROCESS_ SET_ ECHO_ SUPPRESS - SPEEX_
PREPROCESS_ SET_ ECHO_ SUPPRESS_ ACTIVE - SPEEX_
PREPROCESS_ SET_ NOISE_ SUPPRESS - SPEEX_
PREPROCESS_ SET_ PROB_ CONTINUE - SPEEX_
PREPROCESS_ SET_ PROB_ START - SPEEX_
PREPROCESS_ SET_ VAD - UINT8_
MAX - UINT16_
MAX - UINT32_
MAX - UINTPTR_
MAX - UINT_
FAST8_ MAX - UINT_
FAST16_ MAX - UINT_
FAST32_ MAX - UINT_
LEAS T8_ MAX - UINT_
LEAS T16_ MAX - UINT_
LEAS T32_ MAX - WINT_
MAX - WINT_
MIN - _ATFILE_
SOURCE - _BITS_
STDINT_ INTN_ H - _BITS_
STDINT_ LEAST_ H - _BITS_
STDINT_ UINTN_ H - _BITS_
TIME64_ H - _BITS_
TYPESIZES_ H - _BITS_
TYPES_ H - _BITS_
WCHAR_ H - _DEFAULT_
SOURCE - _FEATURES_
H - _POSIX_
C_ SOURCE - _POSIX_
SOURCE - _STDC_
PREDEF_ H - _STDINT_
H - _SYS_
CDEFS_ H - __
FD_ SETSIZE - __
GLIBC_ MINOR__ - __
GLIBC_ USE_ C2X_ STRTOL - __
GLIBC_ USE_ DEPRECATED_ GETS - __
GLIBC_ USE_ DEPRECATED_ SCANF - __
GLIBC_ USE_ IEC_ 60559_ BFP_ EXT - __
GLIBC_ USE_ IEC_ 60559_ BFP_ EXT_ C2X - __
GLIBC_ USE_ IEC_ 60559_ EXT - __
GLIBC_ USE_ IEC_ 60559_ FUNCS_ EXT - __
GLIBC_ USE_ IEC_ 60559_ FUNCS_ EXT_ C2X - __
GLIBC_ USE_ IEC_ 60559_ TYPES_ EXT - __
GLIBC_ USE_ ISOC2X - __
GLIBC_ USE_ LIB_ EXT2 - __
GLIBC__ - __
GNU_ LIBRARY__ - __
HAVE_ GENERIC_ SELECTION - __
INO_ T_ MATCHES_ INO64_ T - __
KERNEL_ OLD_ TIMEVAL_ MATCHES_ TIMEVA L64 - __
LDOUBLE_ REDIRECTS_ TO_ FLOA T128_ ABI - __
OFF_ T_ MATCHES_ OFF64_ T - __
RLIM_ T_ MATCHES_ RLIM64_ T - __
STATFS_ MATCHES_ STATF S64 - __
STDC_ IEC_ 559_ COMPLEX__ - __
STDC_ IEC_ 559__ - __
STDC_ IEC_ 60559_ BFP__ - __
STDC_ IEC_ 60559_ COMPLEX__ - __
STDC_ ISO_ 10646__ - __
SYSCALL_ WORDSIZE - __
TIMESIZE - __
USE_ ATFILE - __
USE_ FORTIFY_ LEVEL - __
USE_ ISOC11 - __
USE_ ISOC95 - __
USE_ ISOC99 - __
USE_ MISC - __
USE_ POSIX - __
USE_ POSI X2 - __
USE_ POSI X199309 - __
USE_ POSI X199506 - __
USE_ POSIX_ IMPLICITLY - __
USE_ XOPE N2K - __
USE_ XOPE N2K8 - __
WORDSIZE - __
WORDSIZE_ TIME64_ COMPA T32 - __
glibc_ c99_ flexarr_ available
Functions
- speex_
decorrelate ⚠ - Remove correlation between the channels by modifying the phase and possibly adding noise in a way that is not (or little) perceptible. @param st Decorrelator state @param in Input audio in interleaved format @param out Result of the decorrelation (out may alias in) @param strength How much alteration of the audio to apply from 0 to 100.
- speex_
decorrelate_ ⚠destroy - Destroy a Decorrelation state @param st State to destroy
- speex_
decorrelate_ ⚠new - Create a state for the channel decorrelation algorithm This is useful for multi-channel echo cancellation only @param rate Sampling rate @param channels Number of channels (it’s a bit pointless if you don’t have at least 2) @param frame_size Size of the frame to process at ones (counting samples per channel)
- speex_
echo_ ⚠cancel - Performs echo cancellation a frame (deprecated)
- speex_
echo_ ⚠cancellation - Performs echo cancellation a frame, based on the audio sent to the speaker (no delay is added to playback in this form)
- speex_
echo_ ⚠capture - Perform echo cancellation using internal playback buffer, which is delayed by two frames to account for the delay introduced by most soundcards (but it could be off!) @param st Echo canceller state @param rec Signal from the microphone (near end + far end echo) @param out Returns near-end signal with echo removed
- speex_
echo_ ⚠ctl - Used like the ioctl function to control the echo canceller parameters
- speex_
echo_ ⚠playback - Let the echo canceller know that a frame was just queued to the soundcard @param st Echo canceller state @param play Signal played to the speaker (received from far end)
- speex_
echo_ ⚠state_ destroy - Destroys an echo canceller state @param st Echo canceller state
- speex_
echo_ ⚠state_ init - Creates a new echo canceller state @param frame_size Number of samples to process at one time (should correspond to 10-20 ms) @param filter_length Number of samples of echo to cancel (should generally correspond to 100-500 ms) @return Newly-created echo canceller state
- speex_
echo_ ⚠state_ init_ mc - Creates a new multi-channel echo canceller state @param frame_size Number of samples to process at one time (should correspond to 10-20 ms) @param filter_length Number of samples of echo to cancel (should generally correspond to 100-500 ms) @param nb_mic Number of microphone channels @param nb_speakers Number of speaker channels @return Newly-created echo canceller state
- speex_
echo_ ⚠state_ reset - Reset the echo canceller to its original state @param st Echo canceller state
- speex_
preprocess ⚠ - Preprocess a frame (deprecated, use speex_preprocess_run() instead)
- speex_
preprocess_ ⚠ctl - Used like the ioctl function to control the preprocessor parameters @param st Preprocessor state @param request ioctl-type request (one of the SPEEX_PREPROCESS_* macros) @param ptr Data exchanged to-from function @return 0 if no error, -1 if request in unknown
- speex_
preprocess_ ⚠estimate_ update - Update preprocessor state, but do not compute the output @param st Preprocessor state @param x Audio sample vector (in only). Must be same size as specified in speex_preprocess_state_init().
- speex_
preprocess_ ⚠run - Preprocess a frame @param st Preprocessor state @param x Audio sample vector (in and out). Must be same size as specified in speex_preprocess_state_init(). @return Bool value for voice activity (1 for speech, 0 for noise/silence), ONLY if VAD turned on.
- speex_
preprocess_ ⚠state_ destroy - Destroys a preprocessor state @param st Preprocessor state to destroy
- speex_
preprocess_ ⚠state_ init - Creates a new preprocessing state. You MUST create one state per channel processed. @param frame_size Number of samples to process at one time (should correspond to 10-20 ms). Must be the same value as that used for the echo canceller for residual echo cancellation to work. @param sampling_rate Sampling rate used for the input. @return Newly created preprocessor state
Type Aliases
- Speex
Decorr State - Speex
Echo State - Internal echo canceller state. Should never be accessed directly.
- Speex
Preprocess State - State of the preprocessor (one per channel). Should never be accessed directly.
- __
blkcnt64_ t - __
blkcnt_ t - __
blksize_ t - __
caddr_ t - __
clock_ t - __
clockid_ t - __
daddr_ t - __dev_t
- __
fsblkcnt64_ t - __
fsblkcnt_ t - __
fsfilcnt64_ t - __
fsfilcnt_ t - __
fsword_ t - __gid_t
- __id_t
- __
ino64_ t - __ino_t
- __
int8_ t - __
int16_ t - __
int32_ t - __
int64_ t - __
int_ least8_ t - __
int_ least16_ t - __
int_ least32_ t - __
int_ least64_ t - __
intmax_ t - __
intptr_ t - __key_t
- __
loff_ t - __
mode_ t - __
nlink_ t - __
off64_ t - __off_t
- __pid_t
- __
quad_ t - __
rlim64_ t - __
rlim_ t - __
sig_ atomic_ t - __
socklen_ t - __
ssize_ t - __
suseconds64_ t - __
suseconds_ t - __
syscall_ slong_ t - __
syscall_ ulong_ t - __
time_ t - __
timer_ t - __
u_ char - __u_int
- __
u_ long - __
u_ quad_ t - __
u_ short - __uid_t
- __
uint8_ t - __
uint16_ t - __
uint32_ t - __
uint64_ t - __
uint_ least8_ t - __
uint_ least16_ t - __
uint_ least32_ t - __
uint_ least64_ t - __
uintmax_ t - __
useconds_ t - int_
fast8_ t - int_
fast16_ t - int_
fast32_ t - int_
fast64_ t - int_
least8_ t - int_
least16_ t - int_
least32_ t - int_
least64_ t - intmax_
t - spx_
int16_ t - spx_
int32_ t - spx_
uint16_ t - spx_
uint32_ t - uint_
fast8_ t - uint_
fast16_ t - uint_
fast32_ t - uint_
fast64_ t - uint_
least8_ t - uint_
least16_ t - uint_
least32_ t - uint_
least64_ t - uintmax_
t